pub struct TypeScriptThresholds {
pub lines: u8,
pub branches: u8,
pub functions: u8,
pub statements: u8,
}Expand description
The four vitest coverage floors, from a [typescript].coverage table. Each
is an independent percent the unit suite must meet — vitest measures all four.
Fields
lines: u8branches: u8functions: u8statements: u8Trait Implementations
Sourceimpl Clone for TypeScriptThresholds
impl Clone for TypeScriptThresholds
Sourcefn clone(&self) -> TypeScriptThresholds
fn clone(&self) -> TypeScriptThresholds
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TypeScriptThresholds
Sourceimpl Debug for TypeScriptThresholds
impl Debug for TypeScriptThresholds
impl Eq for TypeScriptThresholds
Sourceimpl PartialEq for TypeScriptThresholds
impl PartialEq for TypeScriptThresholds
Sourcefn eq(&self, other: &TypeScriptThresholds) -> bool
fn eq(&self, other: &TypeScriptThresholds) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TypeScriptThresholds