pub fn verify_since(
repo: &Path,
scope: &Path,
base: Option<&str>,
) -> Result<Verification>Expand description
Equivalent to verify_extra_scoped with no extra roots and no excludes —
the freshness walk covers only scope.
pub fn verify_since(
repo: &Path,
scope: &Path,
base: Option<&str>,
) -> Result<Verification>Equivalent to verify_extra_scoped with no extra roots and no excludes —
the freshness walk covers only scope.