pub fn parse_normalized_results(json: &str) -> Result<Vec<NormalizedMutant>>Expand description
Parse the normalized results an engine adapter emits — a flat JSON array of
NormalizedMutant (#239).
pub fn parse_normalized_results(json: &str) -> Result<Vec<NormalizedMutant>>Parse the normalized results an engine adapter emits — a flat JSON array of
NormalizedMutant (#239).