Module agents

Module agents 

install: upsert the testing contract into the repository’s agent context file as a marker-delimited, hash-versioned block.

Functions

install
Upsert the managed block into the file at path: create when absent, append when no marker is present, otherwise replace the region between the markers.