install

Function install 

pub fn install(path: &Path) -> Result<()>
Upsert the managed block into the file at path: create the file when absent, append when the markers are missing, otherwise replace only the region between the markers. A current block is a byte-identical no-op.