pub fn unknown_subcommands(
invocations: &[Invocation],
root: &Command,
) -> Vec<Violation>Expand description
Of invocations, the ones whose subcommand chain names a subcommand the clap tree
root no longer exposes.
pub fn unknown_subcommands(
invocations: &[Invocation],
root: &Command,
) -> Vec<Violation>Of invocations, the ones whose subcommand chain names a subcommand the clap tree
root no longer exposes.